@@ -1,7 +1,7 @@
 # Programmer friendly subprocess wrapper.
 #
 # Author: Peter Odding <peter@peterodding.com>
-# Last Change: May 29, 2015
+# Last Change: May 30, 2015
 # URL: https://executor.readthedocs.org
 
 r"""
@@ -62,6 +62,7 @@ integration tools developed using Python:
 
 # Standard library modules.
 import logging
+import multiprocessing
 import socket
 
 # Modules included in our package.
@@ -137,6 +138,24 @@ class AbstractContext(object):
             overrides.setdefault(name, value)
         return overrides
 
+    def prepare(self, *command, **options):
+        """
+        Prepare to execute an external command in the current context.
+
+        :param command: All positional arguments are passed on to the
+                        constructor of the :class:`.ExternalCommand` class.
+        :param options: All keyword arguments are passed on to the
+                        constructor of the :class:`.ExternalCommand` class.
+        :returns: The :class:`.ExternalCommand` object.
+
+        .. note:: After constructing an :class:`.ExternalCommand` object this
+                  method doesn't call :func:`~executor.ExternalCommand.start()`
+                  which means you control if and when the command is started.
+                  This can be useful to prepare a large batch of commands and
+                  execute them concurrently using a :class:`.CommandPool`.
+        """
+        return self.prepare_command(command, options)
+
     def execute(self, *command, **options):
         """
         Execute an external command in the current context.
@@ -158,6 +177,24 @@ class AbstractContext(object):
         cmd.start()
         return cmd
 
+    def test(self, *command, **options):
+        """
+        Execute an external command in the current context and get its status.
+
+        :param command: All positional arguments are passed on to the
+                        constructor of the :class:`.ExternalCommand` class.
+        :param options: All keyword arguments are passed on to the
+                        constructor of the :class:`.ExternalCommand` class.
+        :returns: The value of :attr:`.ExternalCommand.succeeded`.
+
+        This method automatically sets :attr:`~.ExternalCommand.check` to
+        :data:`False` and :attr:`~.ExternalCommand.silent` to :data:`True`.
+        """
+        options.update(check=False, silent=True)
+        cmd = self.prepare_command(command, options)
+        cmd.start()
+        return cmd.succeeded
+
     def capture(self, *command, **options):
         """
         Execute an external command in the current context and capture its output.
@@ -223,6 +260,11 @@ class AbstractContext(object):
         cmd.start()
         return cmd
 
+    @property
+    def cpu_count(self):
+        """The number of CPUs in the system (an integer)."""
+        raise NotImplementedError()
+
     def __enter__(self):
         self.undo_stack.append([])
         return self
@@ -238,6 +280,10 @@ class LocalContext(AbstractContext):
 
     """Context for executing commands on the local system."""
 
+    @property
+    def cpu_count(self):
+        return multiprocessing.cpu_count()
+
     def prepare_command(self, command, options):
         return ExternalCommand(*command, **self.merge_options(options))
 
@@ -261,6 +307,10 @@ class RemoteContext(AbstractContext):
         super(RemoteContext, self).__init__(**options)
         self.ssh_alias = ssh_alias
 
+    @property
+    def cpu_count(self):
+        return int(self.capture('nproc'))
+
     def prepare_command(self, command, options):
         return RemoteCommand(self.ssh_alias, *command, **self.merge_options(options))
 
